# 资源对象相关

## SXResource

#### constructor(type : SXResourceType, path : string)

```
使用资源创建资源

@param type 资源类型
@param path 资源本地路径
```

#### constructor(composite : SXComposite)

```
使用合成创建资源
```

#### constructor(json : string, delegate : SXVideoSequenceDelegate, attr : number)
```
使用视频序列创建 resource

@param json 视频序列json, 参考下文的 SXVideoSequenceJson
@param delegate: SXVideoSequenceDelegate
@param attr : 属性, 传 0
```

#### delete() : void

```
用户自行通过 new 创建的 SXResource, 使用完成后务必手动调用该方法释放
```

#### isValid() : bool
```
检查是否有效

```

#### getResourceType() : SXResourceType
```
获取资源类型
```


#### getResourcePath() : string
```
获取资源路径

@return 资源路径
```

#### getWidth() : number

```
获取宽度, px
```

#### getHeight() : number
```
获取高度, px
```


#### getDuration() : number
```
获取时长
```


#### getFileType() : SXFileType
```
获取文件类型
```


#### getCompositeId() : string

```
获取合成id
```


---
## SXVideoSequenceDelegate

```
视频序列文件处理器
```

#### constructor(listenerId : number)
```
通过 listenerId 创建


示例:
    var jsListener = SXVideoSequenceListener(_sequenceJson);  // _sequecenJson 为 : SXVideoSequenceJson
    var listenerId = SXSdk.registerListener(jsListener);
    var sequenceDelegate = new SXVideoSequenceDelegate(listenerId);
```


#### delete()
```
如果当前delegate 被某个 mediaTrack 使用, 不应调用该方法

@note 调用时会回调 listenter 的 onDestroy 方法
```

---
## SXVideoSequenceListener
```
视频序列监听器, 参考 demo.html 中的示例
 
至少包含以下接口:

- loadFile ( index : number) : Promise 
- onFileUsed(path : string, time : number) : bool
- onFileUnused(path : string) : void 
- onUnusedAll() : void
- onDestroy() : void
 
```

示例:

```
function SXVideoSequenceListener() {

    /**
     * 加载指定位置的文件
     * 
     * @param index, 序列中的位置
     */
    this.loadFile = function(index){
        reture new Promise();
    };

    /**
     * 开始使用文件时回调
     *
     * @param path, 使用的文件本地路径
     * @param time, 文件的局部时间, 秒
     * @param bool, 文件已存在 FS 中返回 true, 不存在返回 false
     */
    this.onFileUsed(path, time){

        return false;
    };


    /**
     * 结束使用文件时回调, 不推荐在这里从 FS 中删除文件
     * @param path, 文件本地路径
     */
    this.onFileUnused(path) {

    };

    /**
     * 结束所有文件使用时回调, 不推荐在这里从 FS 中删除文件
     */
    this.onUnusedAll() {

    };

    /**
     * 销毁 SXVideoSequenceDelegate 时回调
     * @note 当确定删除关联的 MediaTrack 时, 删除SXVideoSequenceDelegate 时会调用该回调,
     *       可以在这里做一些清理工作
     */
    this.onDestroy() {

    }
}

```


---
## SXVideoSequenceJson

```
视频序列数据, 用于创建视频序列资源
```

```
    // SXVideoSequenceJson
    var sequenceJson = {
        width: 0,       // 序列视频宽度, px
        height: 0,      // 序列视频高度, px
        fps: 0,         // 帧率
        rotation: 0,    // 旋转角度
        sample_rate: 0, // 音频采样率
        channels : 0,   // 音频声道数
        list : [
            {
                duration : 10,  // 片段时长, 秒
                path : "",      // 本地文件路径
                url : ""        // 下载链接
            }
        ]
    };

    // 示例 : 使用 json 创建 resource
    var delegate = new SXVideoSequenceDelegate(listenerId);
    var resource = new SXResource(JSON.stringify(sequences), delegate, 0);

```

创建有效 json 的两种方法:
1. 序列中第一个文件本地不存在, 序列视频的所有信息, width, height, fps, rotation 必须为有效值, 可以创建一个有效的 VideoSequence
2. 序列中的第一个片段视频文件已经下载到本地, 此时 除 list 外的选项都可以为 0, SXResource 创建时, 会自动从第一个片段视频读取所需信息


---
## SXVideoSequence

```
视频序列处理类, utils/SXVideoSequence.js

用于获取 SXVideoSequenceJson
```

#### constructor (sequeceJson : SXVideoSequenceJson) 

#### fromM3U8Url(url : string, prefix : string) : SXVideoSequenceJson

```
@param url, m3u8 下载链接
@param prefix, 本地文件保存目录, 以 / 结尾
```

---
## SXRemoteSource

```
远程文件资源示例类, utils/SXRemoteSource.js

实现了视频文件下载到 FS 的逻辑, 具体参考各个方法的实现
```