
## SXTrack

```
轨道基类
```

### 方法

#### getTrackId() : string
```
    /**
     * 获取轨道id
     * @return id
     */
```

#### getTrackType() : SXTrackType
```
 /**
     * 获取轨道类型
     * @return 类型
     */
```

#### getGroupId() : string

```
    /**
     * 获取所在组的id
     * @return 不在组中时返回空字符串
     */
```

#### isValid() : bool
```
 /**
     * 获取轨道是否可用
     * @return 轨道资源错误会造成轨道不可用
     */
```

#### isEnable() : bool
```
    /**
     * 获取是否启用
     * @return true表示启用
     */
```

#### setEnable(enable : bool) : void
```
   /**
     * 设置是否启用
     * @param enable
     */
```

#### getDuration() : number
```
    /**
     * 获取轨道显示时长
     * @return 单位为秒
     */
```

#### setDuration(duration : number) : void
```
  /**
     * 设置轨道时长
     * @param duration 时长
     */
```

#### getStartTime()  : number
```
    /**
     * 获取轨道开始时间
     * @note 素材相对于合成的开始时间
     * @return 开始时间
     */
```

#### setStartTime()  : void
```
    /**
     * 设置轨道的开始时间，即整体移动轨道到对应的时间
     * @note 以轨道开始时间为基准
     * @param position 轨道的开始时间
     */
```

#### setOffsetTime(time : number) : void
```
   /**
     * 设置轨道的自身的偏移时间
     * @note 轨道开始时间（start） + 偏移时间（offset） = 显示时间（display）
     * @param time 偏移时长，须在轨道素材时长范围内
     */
```

#### getOffsetTime() : number
```
    /**
     * 获取轨道自身的偏移时间
     * @note 偏移时间（offset）= 显示时间（display）- 轨道开始时间（start）
     * @return 单位为秒
     */
```

#### moveToTime(time : number) : void

```
    /**
     * 整体移动轨道
     * @note 以轨道开始显示时间为基准
     * @param position 轨道开始显示的时间
     */
```

#### isVisibleAtTime(time : number) : bool

```
    /**
     * 判断是否在可见区间内
     * @param time 时间
     * @return ture表示在时间time上可见
     */
```

#### getDisplayTime() : void
```
    /**
     * 获取轨道开始显示时间
     * @note 素材相对于合成的开始显示时间
     * @return 开始时间
     */
```

#### isLoop() : bool
```
    /**
     * 获取轨道是否循环
     * @return true表示循环
     */
```
#### setLoop(loop : bool) : void

```
    /**
     * 设置轨道时长超出素材时长是否循环，默认不循环
     * @param loop true为循环
     */
```


---
## SXRenderTrack

可渲染轨道基类

#### setPosition(x : number , y : number) : void
```
    /**
     * 设置轨道位置
     * @note 存在对应关键帧时，设置仍然有效但会在渲染时被关键帧动画数据覆盖
     * @param x x坐标
     * @param y y坐标
     */
```

#### getPosition() : SXVec2
```
    /**
     * 获取轨道位置
     * @note 坐标系以左上角为原点，轨道锚点在轨道中心
     * @return 位置坐标
     */
```

#### setScale(x : number, y : number) : void
```
  /**
     * 设置缩放
     * @note 存在对应关键帧时，设置仍然有效但会在渲染时被关键帧动画数据覆盖
     * @param x x缩放
     * @param y y缩放
     */
```

#### getScale() : SXVec2
```
   /**
     * 获取轨道缩放信息
     * @return 缩放默认值为1
     */
```

#### setRotation(degrees : number) : void
```
    /**
     * 设置旋转
     * @note 存在对应关键帧时，设置仍然有效但会在渲染时被关键帧动画数据覆盖
     * @param degrees 旋转角度
     */
```

#### getRotation() : number
```
  /**
     * 获取旋转信息
     * @return 旋转默认值为0
     */
```

#### setOpacity(opacity : number) : void
```
    /**
     * 设置不透明度
     * @note 存在对应关键帧时，设置仍然有效但会在渲染时被关键帧动画数据覆盖
     * @param opacity 不透明度，范围为0-1
     */
```

#### getOpacity() : number
```
    /**
     * 获取不透明度
     * @return 不透明度，默认值为1
     */

```

#### setTransform(affine : SXAffine) : void
```
设置轨道 affine 矩阵

@param affine
```

#### getTransform() : SXAffine

```
获取轨道矩阵信息

@return Affine
```

#### getWidth() : int
```
获取轨道宽度: px

@return int
```

#### getHeight() : int 

```
获取轨道高度: px
```

#### setVerticalFlip(flip : bool) : void

```
设置竖直翻转

@param flip, 是否翻转
```

#### isVerticalFlip() : bool

```
获取轨道是否是竖直翻转

@return bool
```

#### setHorizontalFlip(flip : bool) : void

```
设置水平翻转

@param flip, 是否翻转
```

#### isHorizontalFlip() : bool

```
获取轨道是否是水平翻转

@return bool
```

#### fitToComposite( fit : bool, margin : number) : void
```
是否适配到合成的宽高

@param fit, 是否铺满画面
@param margin, 距离边框的长度 (px)
```

#### addFilter(resource : SXResource, duration : number, index: number) : SXFilterEffect
```
    /**
     * 添加滤镜
     * @param resource 滤镜资源
     * @param duration 滤镜时长
     * @param index 添加后的位置索引，0表示添加到首位，小于0或者大于总数均添加到末尾
     * @return 滤镜对象，失败返回null
     */
```

#### removeFilter(effectId : string) : void
```
移除滤镜

@param effectId ： 滤镜 id
```

#### addVideoEffect(resource : SXResource, duration : number, index: number) : SXVideoEffect
```
    /**
     * 添加视频特效 （通过包来添加类似于主题的特效）
     * @note 视频特效仅局限于轨道自身大小范围内
     * @param resource 视频特效资源
     * @param duration 视频特效时长
     * @param index 添加后的位置索引，0表示添加到首位，小于0或者大于总数均添加到末尾
     * @return 视频特效对象，失败返回nullptr
     */
```

#### removeVideoEffect(effectId : string) : void
```
移除视频特效

@param effectId, 特效 id
```


#### addAnimation(resource : SXResource, duration : number, index: number) : SXAnimationEffect
```
    /**
     * 添加动画特效 （通过包来添加特效动画，不限于矩阵变换动画）
     * @note 动画特效不局限于素材自身，会扩展到合成空间内
     * @param resource 动画特效资源
     * @param duration 动画特效时长
     * @param index 添加后的位置索引，0表示添加到首位，小于0或者大于总数均添加到末尾
     * @return 动画特效对象，失败返回nullptr
     */
```

#### removeAnimation(effectId : string) : void

```
移除视频动画

@param effectId
```
#### addTrackAnimation(resource : SXResource, duration : number, index: number) : SXTrackAnimationEffect
```
   /**
     * 添加轨道动画 （通过包来添加轨道的变换动画）
     * @note 通过包添加的轨道变换动画与关键帧动画不冲突
     * @warning 同一时刻仅有一个动画包会生效
     * @param resource, 轨道动画资源包
     * @param duration, 动画时长
     * @param index 添加后的位置索引，0表示添加到首位，小于0或者大于总数均添加到末尾
     * @return SXVETrackAnimationEffect | nullptr
     * */

```

#### removeTrackAnimation(effectId : string) : void
```
移除轨道动画

@param effectId
```


#### addGenericEffect(type, SXGenericEffectType, duration : number) : SXGenericEffect

```
    /**
     * 添加内置特效
     * @param type 内置特效类型
     * @param duration 内置特效时长
     * @param index 添加后的位置索引，0表示添加到首位，小于0或者大于总数均添加到末尾
     * @return 内置特效，失败返回nullptr
     */
```

#### getGenericEffect(id : string) : SXGenericEffect
```
获取内置特效

@param id, 内置特效id
@return SXGenericEffect
```

#### removeGenericEffect(effectId: string) : void
```
移除内置特效

@param id, 内置特效id
```



---

## SXMediaTrack
继承自 SXRenderTrack

### 方法

#### setSpeed( speed : number)
```
    /**
     * 设置速度，默认值为1
     * @warning 变速会导致时间变化
     * @param speed 速度
     */
```

#### getSpeed() : number
```
    /**
     * 获取播放速度
     * @return 倍速
     */
```

#### setFreezeTime(time : number) : void
```
    /**
     * 定格
     * @param time 相对于start time的局部时间
     */
```

#### getFreezeTime() : number
```
 /**
     * 获取定格时间，无定格则返回-1
     * @return 返回定格时间
     */
```

#### cancelFreeze() : void
```
    /**
     * 取消定格
     */
```

#### setMaskShape(shape : SXShape) : void
```
设置蒙版对象

@param SXShape
```
#### removeMaskShape() : void
```
移除蒙版
```

#### isMaskShapeInverse() : bool
```
蒙版是否是反转

@return bool
```

#### setMaskShapeInverse(inverse : bool) : void
```
设置蒙版是否反转
```


#### setMaskShapeTransform(affine : SXAffine) : void
```
设置蒙版变换
```

#### getMaskShapeTransform() : SXAffine
```
获取蒙版变换
```


#### getMaskShape() : SXShape
```
获取蒙版对象

@return SXShape
```


#### setTransition(resoruce: SXResource, duration : number) : bool
```
    /**
     * 设置转场
     * @note 设置转场后，此轨道会与其后第一个渲染的轨道A进行转场，其他轨道不受影响.
     * 如果*此时*轨道A也需要与其后的轨道进行转场，则A的转场会失效。
     * @warning 请注意转场时长的设置，超过轨道时长可能造成转场效果与预期不符
     * @param resource 转场资源
     * @param duration 转场时长
     * @return 是否添加成功
     */
```

#### removeTransition() : void 
```
移除转场特效
```

#### setTransitionDuration(duration : number) : number
```
设置转场特效的时间

@param duration, 时长 ： 秒
@return number, 返回实际的时长 ： 秒
```

#### getTransitionDuration() : number
```
获取j转场特效的时间

@param trackId, 轨道id
@return number, 返回时长 ： 秒
```

#### hasTransition() : bool
```
检查是否有转场特效

@param trackId, 轨道id
@return bool
```

#### getTransitionResource() : SXResource
```
获取转场的资源

```

#### getAudio() : SXAudio

```
获取关联的音频对象
```

#### replaceMediaResource(resouce : SXResource): bool 
```
    /**
     * 替换媒体资源
     * @warning 替换媒体资源可能引起轨道大小发生变换，暂停播放后调用
     * @param resource 媒体资源
     * @param error 错误码
     * @return 是否替换成功
     */
```


---

## SXStickerTrack

```
贴纸轨道， 继承 SXRenderTrack
```

--- 

## SXTextTrack

```
文字轨道， 继承 SXRenderTrack
```


#### setContent(content : string) : void
```
设置文本内容

@param content, 内容
```

#### setFillColor(color : string) : void
```
设置文本颜色

@param color, 颜色, #RRGGBB 或 #RRGGBBAA
```

#### setStrokeColor(color : string) : void
```
设置描边颜色

@param color, 颜色, #RRGGBB 或 #RRGGBBAA
```

#### setStrokeWidth(width : number) : void
```
设置描边宽度

@param width, 宽度 : px
```

#### setFontSize(size : number) : void
```
设置字体大小

@param size, 大小 : px
```

#### setFontFile(fontPath : string) : void
```
设置字体文件路径

@param fontPath
```

#### setTracking(tracking : number) : void
```
设置字符间距

@param tracking， 字符间距 : px
```

#### setStrokeStyle(style : SXStrokeStyle) : void
```
设置描边样式

@param style
```

#### setTextDirection(direction : SXTextDirectionType) : void
```
设置文字方向

@param direction
```

#### setAlignment(align : SXTextAlignmentType) : void
```
设置对齐类型

@param align
```

#### setTextStyle(resource : SXResouce) : bool
```
设置文字样式路径

@param resource, SXResouce 对象
@return bool
```

#### resetTextStyle() : void
```
重置文字样式
```


#### setBubble(resource : SXResource) : bool
```
设置文字气泡

@param resource, 气泡资源对象
@return bool
```

#### removeBubble() : void
```
移除文字气泡
```

#### addTextAnimation(resource : SXResource, duration: number, index : number) : SXTextAnimationEffect
```
    /**
     * 添加文字动画
     * @param resource 文字动画资源
     * @param duration 文字动画时长
     * @param index 添加后的位置索引，0表示添加到首位，小于0或者大于总数均添加到末尾
     * @return 文字动画对象，失败时返回nullptr
     */

```

#### removeTextAnimationEffect(effectId : string) : void

```
移除文字动画

@param effectId

```

---
## SXAudio
```
媒体轨道的音频对象
```


#### setSpeed( speed : number)
```
    /**
     * 设置音频速度，默认值为1
     * @warning 变速会导致音频时间变化
     * @param speed 速度
     */
```

#### getSpeed() : number
```
    /**
     * 获取音频播放速度
     * @return 倍速
     */
```

#### setEnable( speed : bool)
```
    /**
     * 设置是否启用
     * @param enable
     */
```

#### isEnable( ) : bool
```
    /**
     * 获取是否启用
     * @return true表示启用
     */
```

#### setFadeInDuration( fadein : number)
```
  /**
     * 设置淡入时长
     * @note 时长不受变速影响
     * @param fade 时长，单位为秒
     */
```

#### getFadeInDuration( ) : number
```
    /**
     * 获取淡入时长
     * @return 单位为秒
     */
```

#### setFadeOutDuration( fadein : number)
```
 /**
     * 设置淡出时长
     * @note 时长不受变速影响
     * @param fade 时长，单位为秒
     */
```

#### getFadeOutDuration( ) : number
```
   /**
     * 获取淡出时长
     * @return 单位为秒
     */
```

#### setVolume( volume : number)
```
    /**
     * 设置音量大小，默认音量为1
     * @param volume 音量
     */
```

#### getVolume( ) : number
```
  /**
     * 获取音量
     * @return 音量
     */
```

#### setPitch( pitch : number)
```
    /**
     * 设置音调大小，默认值为1
     * @param pitch 音调大小
     */
```

#### getPitch( ) : number
```
    /**
     * 获取音调
     * @return 音调
     */
```


---
## SXAudioTrack
```
音频轨道 继承 SXTrack
```

#### setSpeed( speed : number)
```
    /**
     * 设置音频速度，默认值为1
     * @warning 变速会导致音频时间变化
     * @param speed 速度
     */
```

#### getSpeed() : number
```
    /**
     * 获取音频播放速度
     * @return 倍速
     */
```

#### setFadeInDuration( fadein : number)
```
  /**
     * 设置淡入时长
     * @note 时长不受变速影响
     * @param fade 时长，单位为秒
     */
```

#### getFadeInDuration( ) : number
```
    /**
     * 获取淡入时长
     * @return 单位为秒
     */
```

#### setFadeOutDuration( fadein : number)
```
 /**
     * 设置淡出时长
     * @note 时长不受变速影响
     * @param fade 时长，单位为秒
     */
```

#### getFadeOutDuration( ) : number
```
   /**
     * 获取淡出时长
     * @return 单位为秒
     */
```

#### setVolume( volume : number)
```
    /**
     * 设置音量大小，默认音量为1
     * @param volume 音量
     */
```

#### getVolume( ) : number
```
  /**
     * 获取音量
     * @return 音量
     */
```

#### setPitch( pitch : number)
```
    /**
     * 设置音调大小，默认值为1
     * @param pitch 音调大小
     */
```

#### getPitch( ) : number
```
    /**
     * 获取音调
     * @return 音调
     */
```
#### getResource() : SXResource
```
 /**
     * 获取音频的资源对象
     * @return 资源
     */
```
